@@ -1,5 +1,5 @@
 """
-# AST Parser
+# AST Parser.
 
 Collection of tools for analyzing AST and also rendering it back to a valid Python code.
 
@@ -17,7 +17,8 @@ Use `handsdown.ast_parser.node_records.ModuleRecord` to parse the source code.
     source_path = Path("my_module.py")
     import_string = ImportString("my_module")
     module_record = ModuleRecord.create_from_source(source_path, import_string)
-    module_record.build_children() # generate records for imports, classes, attributes and function in module
+    module_record.build_children() # generate records for imports, classes, attributes
+    and function in module
 
     function_record = module_record.function_records[0] # get the first function in module
     print(function_record.render(allow_multiline=True)) # print function definition
