@@ -6,8 +6,9 @@ import enum
 
 class RenderPart(enum.Enum):
     """
-    Special render part for `handsdown.ast_parser.node_records.node_record.NodeRecord.render`
-    function.
+    Special render part.
+
+    For `handsdown.ast_parser.node_records.node_record.NodeRecord.render` function.
     """
 
     # Replaced with a line break for a multi-line render, does not change indent
@@ -34,8 +35,7 @@ class RenderPart(enum.Enum):
     # Replaced with a comma in a multi-line render
     MULTI_LINE_COMMA = "MULTI_LINE_COMMA"
 
-    def is_line_break(self):
-        # type: () -> bool
+    def is_line_break(self) -> bool:
         """
         Check if it is a mandatory line break.
 
